@@ -1,14 +1,23 @@
 import * as _ from 'lodash';
 import { K8sResourceKind } from '@console/internal/module/k8s';
 import { TRIGGERS_ANNOTATION } from '@console/shared';
+import { UNASSIGNED_LABEL } from '../const';
 
-export const getAppLabels = (
-  name: string,
-  application?: string,
-  imageStreamName?: string,
-  selectedTag?: string,
-  namespace?: string,
-) => {
+export const getAppLabels = ({
+  name,
+  applicationName,
+  imageStreamName,
+  runtimeIcon,
+  selectedTag,
+  namespace,
+}: {
+  name: string;
+  applicationName?: string;
+  imageStreamName?: string;
+  runtimeIcon?: string;
+  selectedTag?: string;
+  namespace?: string;
+}) => {
   const labels = {
     app: name,
     'app.kubernetes.io/instance': name,
@@ -19,8 +28,15 @@ export const getAppLabels = (
     }),
   };
 
-  if (application && application.trim().length > 0) {
-    labels['app.kubernetes.io/part-of'] = application;
+  if (runtimeIcon) {
+    labels['app.openshift.io/runtime'] = runtimeIcon;
+  }
+  if (
+    applicationName &&
+    applicationName !== UNASSIGNED_LABEL &&
+    applicationName.trim().length > 0
+  ) {
+    labels['app.kubernetes.io/part-of'] = applicationName;
   }
   if (selectedTag) {
     labels['app.openshift.io/runtime-version'] = selectedTag;
