@@ -143,11 +143,11 @@ export const DeploymentConfigDetailsList = ({ dc }) => {
             obj={dc}
             path="spec.strategy.rollingParams.maxUnavailable"
           >
-            {dc.spec.strategy.rollingUpdate.maxUnavailable || 1} of{' '}
+            {dc.spec.strategy.rollingUpdate.maxUnavailable ?? 1} of{' '}
             {pluralize(dc.spec.replicas, 'pod')}
           </DetailsItem>
           <DetailsItem label="Max Surge" obj={dc} path="spec.strategy.rollingParams.maxSurge">
-            {dc.spec.strategy.rollingUpdate.maxSurge || 1} greater than{' '}
+            {dc.spec.strategy.rollingUpdate.maxSurge ?? 1} greater than{' '}
             {pluralize(dc.spec.replicas, 'pod')}
           </DetailsItem>
         </>
